@@ -1,7 +1,7 @@
 package Bencher::Scenario::TreeObject::Startup;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-31'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use Bencher::ScenarioUtil::TreeObject;
 
@@ -33,7 +33,7 @@ Bencher::Scenario::TreeObject::Startup - Benchmark startup of various tree class
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::TreeObject::Startup (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-03-30.
+This document describes version 0.03 of Bencher::Scenario::TreeObject::Startup (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-03-31.
 
 =head1 SYNOPSIS
 
@@ -47,37 +47,25 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Tree::Object::Hash> 0.06
-
-L<Tree::Object::Hash::ChildrenAsList> 0.06
-
-L<Tree::Object::Array> 0.06
+L<Tree::ObjectXS::Hash> 0.02
 
 L<Tree::ObjectXS::Array> 0.02
 
 L<Tree::Object::Array::Glob> 0.06
 
-L<Tree::ObjectXS::Hash> 0.02
+L<Tree::Object::Array> 0.06
+
+L<Tree::Object::Hash> 0.06
+
+L<Tree::Object::Hash::ChildrenAsList> 0.06
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Tree::Object::Hash (perl_code)
+=item * Tree::ObjectXS::Hash (perl_code)
 
-L<Tree::Object::Hash>
-
-
-
-=item * Tree::Object::Hash::ChildrenAsList (perl_code)
-
-L<Tree::Object::Hash::ChildrenAsList>
-
-
-
-=item * Tree::Object::Array (perl_code)
-
-L<Tree::Object::Array>
+L<Tree::ObjectXS::Hash>
 
 
 
@@ -93,9 +81,21 @@ L<Tree::Object::Array::Glob>
 
 
 
-=item * Tree::ObjectXS::Hash (perl_code)
+=item * Tree::Object::Array (perl_code)
 
-L<Tree::ObjectXS::Hash>
+L<Tree::Object::Array>
+
+
+
+=item * Tree::Object::Hash (perl_code)
+
+L<Tree::Object::Hash>
+
+
+
+=item * Tree::Object::Hash::ChildrenAsList (perl_code)
+
+L<Tree::Object::Hash::ChildrenAsList>
 
 
 
@@ -110,13 +110,13 @@ Benchmark with default options (C<< bencher -m TreeObject::Startup >>):
  +------------------------------------+-----------+------------------------+------------+---------+---------+
  | participant                        | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +------------------------------------+-----------+------------------------+------------+---------+---------+
- | Tree::ObjectXS::Hash               | 4e+01     | 18                     | 1          | 0.00044 | 20      |
- | Tree::ObjectXS::Array              | 36        | 14                     | 1          | 0.00016 | 20      |
- | Tree::Object::Hash                 | 32        | 10                     | 1.2        | 0.00016 | 20      |
- | Tree::Object::Array::Glob          | 31        | 9                      | 1.2        | 3.2e-05 | 20      |
- | Tree::Object::Array                | 31        | 9                      | 1.2        | 6.9e-05 | 20      |
- | Tree::Object::Hash::ChildrenAsList | 31        | 9                      | 1.2        | 5.8e-05 | 20      |
- | perl -e1 (baseline)                | 22        | 0                      | 1.7        | 5.9e-05 | 20      |
+ | Tree::Object::Array                | 4e+01     | 17                     | 1          | 0.00045 | 20      |
+ | Tree::ObjectXS::Array              | 38        | 15                     | 1.1        | 0.00033 | 21      |
+ | Tree::Object::Array::Glob          | 4e+01     | 17                     | 1          | 0.00071 | 21      |
+ | Tree::Object::Hash                 | 4e+01     | 17                     | 1          | 0.00062 | 20      |
+ | Tree::ObjectXS::Hash               | 35        | 12                     | 1.2        | 8.7e-05 | 20      |
+ | Tree::Object::Hash::ChildrenAsList | 3e+01     | 7                      | 1          | 0.00038 | 20      |
+ | perl -e1 (baseline)                | 23        | 0                      | 1.8        | 3.7e-05 | 20      |
  +------------------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
