@@ -1,7 +1,7 @@
 package Bencher::Scenario::TreeObject::descendants;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-31'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -41,7 +41,7 @@ Bencher::Scenario::TreeObject::descendants - Benchmark descendants()
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::TreeObject::descendants (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-03-30.
+This document describes version 0.03 of Bencher::Scenario::TreeObject::descendants (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-03-31.
 
 =head1 SYNOPSIS
 
@@ -129,6 +129,10 @@ Code template:
 
 =over
 
+=item * tiny1 (3 nodes)
+
+A tree with height=1 and 2 children per non-leaf nodes, nodes=1 + 2 = 3
+
 =item * small1 (31 nodes)
 
 A tree with height=4 and 2 children per non-leaf nodes, nodes=1 + 2 + 4 + 8 + 16 = 31
@@ -156,12 +160,12 @@ Benchmark with C<< bencher -m TreeObject::descendants --include-datasets 'small1
  +------------------------------------+-----------+-----------+------------+---------+---------+
  | participant                        | rate (/s) | time (μs) | vs_slowest | errors  | samples |
  +------------------------------------+-----------+-----------+------------+---------+---------+
- | Tree::Object::Array::Glob          | 7.1e+03   | 1.4e+02   | 1          | 1.6e-07 | 20      |
- | Tree::Object::Hash                 | 8.7e+03   | 1.2e+02   | 1.2        | 1.9e-07 | 25      |
- | Tree::Object::Array                | 9130.32   | 109.525   | 1.29226    | 9.2e-11 | 25      |
- | Tree::Object::Hash::ChildrenAsList | 1.03e+04  | 97.1      | 1.46       | 2.2e-08 | 30      |
- | Tree::ObjectXS::Hash               | 1e+04     | 96        | 1.5        | 1e-07   | 33      |
- | Tree::ObjectXS::Array              | 1.07e+04  | 93.1      | 1.52       | 2.1e-08 | 32      |
+ | Tree::Object::Array::Glob          | 1.4e+04   | 70        | 1          | 1.1e-07 | 20      |
+ | Tree::Object::Hash                 | 1.73e+04  | 57.9      | 1.2        | 2.1e-08 | 31      |
+ | Tree::Object::Array                | 1.84e+04  | 54.4      | 1.28       | 2.6e-08 | 21      |
+ | Tree::ObjectXS::Hash               | 2.08e+04  | 48        | 1.45       | 4e-08   | 20      |
+ | Tree::Object::Hash::ChildrenAsList | 2.1e+04   | 47.5      | 1.46       | 1.3e-08 | 20      |
+ | Tree::ObjectXS::Array              | 21081.7   | 47.4345   | 1.46605    | 1.1e-11 | 20      |
  +------------------------------------+-----------+-----------+------------+---------+---------+
 
 
@@ -170,12 +174,12 @@ Benchmark with C<< bencher -m TreeObject::descendants --include-datasets 'medium
  +------------------------------------+-----------+-----------+------------+---------+---------+
  | participant                        | rate (/s) | time (ms) | vs_slowest | errors  | samples |
  +------------------------------------+-----------+-----------+------------+---------+---------+
- | Tree::Object::Array::Glob          | 24        | 42        | 1          | 6.7e-05 | 21      |
- | Tree::Object::Hash                 | 28        | 36        | 1.2        | 7.4e-05 | 20      |
- | Tree::Object::Hash::ChildrenAsList | 32        | 31        | 1.3        | 3.5e-05 | 20      |
- | Tree::Object::Array                | 32        | 31        | 1.3        | 4.5e-05 | 20      |
- | Tree::ObjectXS::Hash               | 35.6      | 28.1      | 1.48       | 1.8e-05 | 20      |
- | Tree::ObjectXS::Array              | 36        | 28        | 1.5        | 3.2e-05 | 21      |
+ | Tree::Object::Array::Glob          | 25        | 41        | 1          | 0.0001  | 20      |
+ | Tree::Object::Hash                 | 28        | 36        | 1.1        | 0.00013 | 20      |
+ | Tree::Object::Hash::ChildrenAsList | 33        | 31        | 1.3        | 0.00016 | 21      |
+ | Tree::Object::Array                | 33        | 30        | 1.3        | 0.00013 | 20      |
+ | Tree::ObjectXS::Array              | 36        | 28        | 1.5        | 9e-05   | 20      |
+ | Tree::ObjectXS::Hash               | 37        | 27        | 1.5        | 8.8e-05 | 20      |
  +------------------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
