@@ -1,7 +1,7 @@
 package Bencher::ScenarioUtil::TreeObject;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-31'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 our %classes = (
     'Tree::Object::Hash'                 => {backend=>'hash'},
@@ -14,10 +14,15 @@ our %classes = (
 );
 
 our @trees_datasets = (
+    {
+        name => 'tiny1 (3 nodes)',
+        summary => 'A tree with height=1 and 2 children per non-leaf nodes, nodes=1 + 2 = 3',
+        args => {height=>1, num_children=>2},
+    },
     {
         name => 'small1 (31 nodes)',
         summary => 'A tree with height=4 and 2 children per non-leaf nodes, nodes=1 + 2 + 4 + 8 + 16 = 31',
-        args => {height=>5, num_children=>2},
+        args => {height=>4, num_children=>2},
     },
     {
         name => 'small2 (364 nodes)',
@@ -63,7 +68,7 @@ Bencher::ScenarioUtil::TreeObject - Utility routines
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::ScenarioUtil::TreeObject (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-03-30.
+This document describes version 0.03 of Bencher::ScenarioUtil::TreeObject (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-03-31.
 
 =head1 HOMEPAGE
 
